Commande Linux gpasswd
Linux gpasswd est un outil de gestion des fichiers de groupe /etc/group et /etc/gshadow sous Linux, utilisé pour ajouter un utilisateur à un groupe ou retirer un utilisateur d'un groupe.
Syntaxe
gpasswd [可选项] 组名
Paramètres optionnels:
- -a : Ajouter un utilisateur au groupe ;
- -d : Retirer un utilisateur du groupe ;
- -A : Spécifier un administrateur ;
- -M : Spécifier les membres du groupe, de manière similaire à l'objectif de -A ;
- -r : Supprimer le mot de passe ;
- -R : Restreindre les utilisateurs pour qu'ils ne puissent pas se connecter au groupe ; seuls les membres du groupe peuvent le rejoindre en utilisant newgrp.
Exemples
Par exemple, le système dispose d'un compte peter, qui n'est pas membre du groupe groupname. Pour utiliser newgrp, le mot de passe est requis.
gpasswd groupname
Cela permet à l'utilisateur de devenir temporairement membre du groupe ; par la suite, les fichiers créés par peter auront également pour groupe groupname. Ainsi, cette méthode peut temporairement permettre à peter d'utiliser un groupe différent lors de la création de fichiers, au lieu du groupe auquel peter appartient.
Par conséquent, utiliser gpasswd groupname pour définir un mot de passe permet à ceux qui connaissent le mot de passe du groupe de disposer temporairement des fonctionnalités du groupe groupname.
gpasswd -A peter users
De cette manière, peter devient l'administrateur du groupe users et peut effectuer les opérations suivantes :
gpasswd -a mary users gpasswd -a allen users
Remarque: Pour ajouter un utilisateur à un groupe, vous pouvez utiliserusermod -G group_name user_nameCette commande peut ajouter un utilisateur à un groupe spécifié, mais les groupes précédemment ajoutés seront effacés.
Par conséquent, si vous souhaitez ajouter un utilisateur à un groupe tout en conservant les groupes ajoutés précédemment, veuillez utiliser la commande gpasswd pour ajouter l'utilisateur :
gpasswd -a user_name group_nameAutres extensions
Collection de commandes Linux